package Test::MyCmd;
use Any::Moose;

extends qw(MooseX::App::Cmd);

1;
